import pkg_resources  # type: ignore

__version__ = pkg_resources.get_distribution("crusher").version
